package com.zehong.web.controller.transaction;

import java.util.List;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zehong.common.annotation.Log;
import com.zehong.common.core.controller.BaseController;
import com.zehong.common.core.domain.AjaxResult;
import com.zehong.common.enums.BusinessType;
import com.zehong.system.domain.TTradeChangeInfo;
import com.zehong.system.service.ITTradeChangeInfoService;
import com.zehong.common.utils.poi.ExcelUtil;
import com.zehong.common.core.page.TableDataInfo;

/**
 * 交易项目转移信息Controller
 * 
 * @author zehong
 * @date 2023-09-12
 */
@RestController
@RequestMapping("/trade/changeInfo")
public class TTradeChangeInfoController extends BaseController
{
    @Autowired
    private ITTradeChangeInfoService tTradeChangeInfoService;

    /**
     * 查询交易项目转移信息列表
     */
    @GetMapping("/list")
    public TableDataInfo list(TTradeChangeInfo tTradeChangeInfo)
    {
        startPage();
        List<TTradeChangeInfo> list = tTradeChangeInfoService.selectTTradeChangeInfoList(tTradeChangeInfo);
        return getDataTable(list);
    }

    /**
     * 导出交易项目转移信息列表
     */
    @Log(title = "交易项目转移信息", businessType = BusinessType.EXPORT)
    @GetMapping("/export")
    public AjaxResult export(TTradeChangeInfo tTradeChangeInfo)
    {
        List<TTradeChangeInfo> list = tTradeChangeInfoService.selectTTradeChangeInfoList(tTradeChangeInfo);
        ExcelUtil<TTradeChangeInfo> util = new ExcelUtil<TTradeChangeInfo>(TTradeChangeInfo.class);
        return util.exportExcel(list, "交易项目转移信息数据");
    }

    /**
     * 获取交易项目转移信息详细信息
     */
    @GetMapping(value = "/{changeId}")
    public AjaxResult getInfo(@PathVariable("changeId") Long changeId)
    {
        return AjaxResult.success(tTradeChangeInfoService.selectTTradeChangeInfoById(changeId));
    }

    /**
     * 新增交易项目转移信息
     */
    @Log(title = "交易项目转移信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TTradeChangeInfo tTradeChangeInfo)
    {
        return toAjax(tTradeChangeInfoService.insertTTradeChangeInfo(tTradeChangeInfo));
    }

    /**
     * 修改交易项目转移信息
     */
    @Log(title = "交易项目转移信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TTradeChangeInfo tTradeChangeInfo)
    {
        return toAjax(tTradeChangeInfoService.updateTTradeChangeInfo(tTradeChangeInfo));
    }

    /**
     * 删除交易项目转移信息
     */
    @Log(title = "交易项目转移信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{changeIds}")
    public AjaxResult remove(@PathVariable Long[] changeIds)
    {
        return toAjax(tTradeChangeInfoService.deleteTTradeChangeInfoByIds(changeIds));
    }
}
